# ConvectionDiffusion #

**UG4-Plugin** implementing fe-/fv-discretizations for convection-diffusion problems.

Copyright 2009-2015 Goethe Center for Scientific Computing, University Frankfurt

Please install/clone this repository through UG4's package manager
[ughub](https://github.com/UG4/ughub).
